fn totp_credential_to_totp(cxf_totp: &TotpCredential) -> TotpExpand description
Convert CXF TotpCredential to Bitwarden’s Totp struct This ensures we use the exact same encoding and formatting as Bitwarden’s core implementation
fn totp_credential_to_totp(cxf_totp: &TotpCredential) -> TotpConvert CXF TotpCredential to Bitwarden’s Totp struct This ensures we use the exact same encoding and formatting as Bitwarden’s core implementation